/***************************************************************************

 Author        : CAST 

 Date          : March 10th, 2011

 File          : ADF4158_IO.c

 Hardware      : ADuC7026 and ADF7021
	
***************************************************************************/
#include <ADuC7026.h>
#include "ADuC7026Driver.h"
#include "ADF7021_IO.h"

unsigned long int ADF7021Registers[16];

void ADF7021Registers_TRANSMITTER_config (void)
{
	ADF7021Registers[0]=N_REGISTER_0|TRANSMIT|INTEGER_N|FRACTIONAL_N_Tx;
	ADF7021Registers[1]=VCO_OSCILLATOR_REGISTER_1|XOSC_ENABLE|R_COUNTER_DIVIDE_RATIO|XTAL_BIAS|CP_CURRENT|VCO_LOOP_CONDITION_ON|VCO_BIASCURRENT;
	ADF7021Registers[2]=TRANSMIT_MODULATION_REGISTER_2|PA_ENABLE|PA_BIAS|POWER_AMPLIFIER|Tx_FREQUENCY_DEVIATION|FSK_2|TxINVERT_NORMAL;
	ADF7021Registers[3]=TRANSMIT_RECEIVE_CLOCK_REGISTER_3|AGC_CLK_DIVIDE|SEQUENCER_CLK_DIVIDE|CDR_CLK_DIVIDE|DEM_CLK_DIVIDE|BBOS_CLK_DIVIDE;
	ADF7021Registers[4]=DEMODULATOR_SETUP_REGISTER_4|IF_BW_25kHz|POST_DEMOD_BW|DISCRIMINATOR_BW|Rx_INVERT_NORMAL|DEMOD_SCHEME_2FSK_CORRELATOR;
	ADF7021Registers[5]=IF_FILTER_SETUP_REGISTER_5|IF_CAL_COARSE|IF_FILTER_DIVIDER|IF_FILTER_ADJUST|IR_PHASE_ADJUST_MAG|IR_GAIN_ADJUST_MAG;
	ADF7021Registers[6]=IF_FINE_CAL_SETUP_REGISTER_6|IF_CAL_LOWER_TONE_DIVIDE|IF_CAL_UPPER_TONE_DIVIDE|IF_CAL_DWELL_TIME|IR_CAL_SOURCEDRIVE_LEVEL_OFF;
	ADF7021Registers[7]=READBACK_SETUP_REGISTER_7;
	ADF7021Registers[8]=POWER_DOWN_TEST_REGISTER_8;
	ADF7021Registers[9]=AGC_REGISTER_9|AGC_LOW_THRESHOLD|AGC_HIGH_THRESHOLD|AUTO_AGC|LNA_GAIN_3|FILTER_GAIN_8|LNA_CURRENT;
	ADF7021Registers[10]=AFC_REGISTER_10|AFC_SCALING_FACTOR|KI|KP|MAX_AFC_RANGE;
	ADF7021Registers[11]=SYNC_WORD_DETECT_REGISTER_11|SYNC_24_BITS|SYNC_BYTE_SEQUENCE|ACCEPT_0_ERRORS;
	ADF7021Registers[12]=SWD_THRESHOLD_SETUP_REGISTER_12|THRESHOLD_FREE_RUNNING|SWD_HIGH_AFTER_NEXT_SYNCWORD_INTERRUPT_PIN_HIGH|DATA_PACKET_LENGTH;
	ADF7021Registers[13]=FSK_3_4FSK_DEMOD_REGISTER_13;
	ADF7021Registers[14]=TEST_DAC_REGISTER_14;
	ADF7021Registers[15]=TEST_MODE_REGISTER_15;


}

void ADF7021Registers_RECEIVER_config (void)
{
	ADF7021Registers[0]=N_REGISTER_0|RECEIVE|INTEGER_N|FRACTIONAL_N_Rx;
	ADF7021Registers[1]=VCO_OSCILLATOR_REGISTER_1|XOSC_ENABLE|R_COUNTER_DIVIDE_RATIO|XTAL_BIAS|CP_CURRENT|VCO_LOOP_CONDITION_ON|VCO_BIASCURRENT;
	ADF7021Registers[2]=TRANSMIT_MODULATION_REGISTER_2|PA_ENABLE|PA_BIAS|POWER_AMPLIFIER|Tx_FREQUENCY_DEVIATION|FSK_2|TxINVERT_NORMAL;
	ADF7021Registers[3]=TRANSMIT_RECEIVE_CLOCK_REGISTER_3|AGC_CLK_DIVIDE|SEQUENCER_CLK_DIVIDE|CDR_CLK_DIVIDE|DEM_CLK_DIVIDE|BBOS_CLK_DIVIDE;
	ADF7021Registers[4]=DEMODULATOR_SETUP_REGISTER_4|IF_BW_25kHz|POST_DEMOD_BW|DISCRIMINATOR_BW|Rx_INVERT_NORMAL|DEMOD_SCHEME_2FSK_CORRELATOR;
	ADF7021Registers[5]=IF_FILTER_SETUP_REGISTER_5|IF_CAL_COARSE|IF_FILTER_DIVIDER|IF_FILTER_ADJUST|IR_PHASE_ADJUST_MAG|IR_GAIN_ADJUST_MAG;
	ADF7021Registers[6]=IF_FINE_CAL_SETUP_REGISTER_6|IF_CAL_LOWER_TONE_DIVIDE|IF_CAL_UPPER_TONE_DIVIDE|IF_CAL_DWELL_TIME|IR_CAL_SOURCEDRIVE_LEVEL_OFF;
	ADF7021Registers[7]=READBACK_SETUP_REGISTER_7;
	ADF7021Registers[8]=POWER_DOWN_TEST_REGISTER_8;
	ADF7021Registers[9]=AGC_REGISTER_9|AGC_LOW_THRESHOLD|AGC_HIGH_THRESHOLD|AUTO_AGC|LNA_GAIN_3|FILTER_GAIN_8|LNA_CURRENT;
	ADF7021Registers[10]=AFC_REGISTER_10|AFC_SCALING_FACTOR|KI|KP|MAX_AFC_RANGE;
	ADF7021Registers[11]=SYNC_WORD_DETECT_REGISTER_11|SYNC_24_BITS|SYNC_BYTE_SEQUENCE|ACCEPT_0_ERRORS;
	ADF7021Registers[12]=SWD_THRESHOLD_SETUP_REGISTER_12|THRESHOLD_FREE_RUNNING|SWD_HIGH_AFTER_NEXT_SYNCWORD_INTERRUPT_PIN_HIGH|DATA_PACKET_LENGTH;
	ADF7021Registers[13]=FSK_3_4FSK_DEMOD_REGISTER_13;
	ADF7021Registers[14]=TEST_DAC_REGISTER_14;
	ADF7021Registers[15]=TEST_MODE_REGISTER_15;

}
//---------------------------------
//void WriteToADF4158(unsigned long int *buff , char Adress)
//---------------------------------

void WriteToADF7021_Registers(unsigned long int *buff , char Adress)
{
    unsigned	char      i;
	unsigned	long int  tempmy ;
	
//	SET_DATA_OUT();	
	my_delay(1);
	CLR_SLE();
	CLR_SCLK();
    tempmy =*(buff+Adress);
	for(i=0; i<32; i++)
	{
			if(tempmy & 0x80000000)
			{
				SET_SDATA();	  //Send one to SDO pin
			}
			else
			{
				CLR_SDATA();	  //Send zero to SDO pin
			}
			my_delay(1);
			SET_SCLK();
			tempmy <<= 1;	//Rotate data
			CLR_SCLK();		
	}
	my_delay(3);
	SET_SLE();
	my_delay(1);
	CLR_SLE();
}

void TRANSMITTER_GPIO_config(void)
{

SET_SLE_OUT();         //P4.3->OUT SLE
SET_SCLK_OUT();        //P1.3->OUT SCLK
SET_SDATA_OUT();       //P4.5->OUT SDATA
SET_CE_OUT();          //P4.4->OUT CE

SET_TxRxCLK_IN();       //P1.6->IN TxRxCLK
SET_TxRxDATA_OUT();       //P1.5->OUT TxRxDATA

SET_SREAD_IN();       //P1.2->IN SREAD

SET_SWD_IN();         //P1.4->INT SWD IRQ2

}

void RECEIVER_GPIO_config(void)
{
SET_TxRxDATA_IN();       //P1.5->IN TxRxDATA
SET_SLE_OUT();         //P4.3->OUT SLE
SET_SCLK_OUT();        //P1.3->OUT SCLK
SET_SDATA_OUT();       //P4.5->OUT SDATA
SET_CE_OUT();          //P4.3->OUT CE

SET_TxRxCLK_IN();       //P1.6->IN TxRxCLK
//SET_TxRxDATA_OUT();       //P1.5->IN TxRxDATA


SET_SREAD_IN();       //P1.2->IN SREAD

SET_SWD_IN();         //P1.4->INT SWD IRQ2

}
